@@ -5,12 +5,16 @@ import random
 class PleEnvAdapter(EnvAdapter):
     """Pygame learning env adapter"""
 
+    def get_input_shape(self):
+        return (len(self.env.getGameState()),)
+
     def reset(self):
         self.env.reset_game()
 
     def step(self, action) -> (object, float, bool):
         observation = self.env.getGameState()
-        reward = self.env.act(action)
+        observation = [val for key, val in observation.items()]
+        reward = self.env.act(self.env.getActionSet()[action])
         done = self.env.game_over()
         return observation, reward, done
 
@@ -18,4 +22,4 @@ class PleEnvAdapter(EnvAdapter):
         return len(self.env.getActionSet())
 
     def get_random_action(self):
-        return random.choice(self.env.getActionSet())
+        return random.randint(0, len(self.env.getActionSet()) - 1)
